@@ -1,5 +1,5 @@
-from office365.directory.directory_object_collection import DirectoryObjectCollection
-from office365.directory.directory_object import DirectoryObject
+from office365.directory.object_collection import DirectoryObjectCollection
+from office365.directory.object import DirectoryObject
 from office365.directory.extensions.extension_property import ExtensionProperty
 from office365.directory.key_credential import KeyCredential
 from office365.directory.password_credential import PasswordCredential
@@ -25,7 +25,7 @@ class Application(DirectoryObject):
 
         :param str display_name: App display name
         """
-        params = PasswordCredential(displayName=display_name)
+        params = PasswordCredential(display_name=display_name)
         result = ClientResult(self.context, params)
         qry = ServiceOperationQuery(self, "addPassword", None, params, None, result)
         self.context.add_query(qry)
