@@ -13,11 +13,11 @@ from office365.runtime.queries.delete_entity import DeleteEntityQuery
 from office365.runtime.queries.service_operation import ServiceOperationQuery
 from office365.runtime.queries.update_entity import UpdateEntityQuery
 from office365.runtime.paths.resource_path import ResourcePath
-from office365.sharepoint.portal.site_status import SiteStatus
+from office365.sharepoint.portal.sites.status import SiteStatus
 from office365.sharepoint.publishing.pages.service import SitePageService
 from office365.sharepoint.request_user_context import RequestUserContext
 from office365.sharepoint.sites.site import Site
-from office365.sharepoint.tenant.administration.hub_site_collection import HubSiteCollection
+from office365.sharepoint.tenant.administration.hubsites.collection import HubSiteCollection
 from office365.sharepoint.webs.context_web_information import ContextWebInformation
 from office365.sharepoint.webs.web import Web
 from office365.runtime.compat import urlparse, is_absolute_url, get_absolute_url
@@ -79,17 +79,19 @@ class ClientContext(ClientRuntimeContext):
         ctx.after_execute(_init_context_for_web)
         return ctx
 
-    def with_client_certificate(self, tenant, client_id, thumbprint, cert_path, **kwargs):
+    def with_client_certificate(self, tenant, client_id, thumbprint, cert_path=None, private_key=None, scopes=None):
         """Creates authenticated SharePoint context via certificate credentials
 
         :param str tenant: Tenant name
-        :param str cert_path: Path to A PEM encoded certificate private key.
+        :param str or None cert_path: Path to A PEM encoded certificate private key.
+        :param str or None private_key: A PEM encoded certificate private key.
         :param str thumbprint: Hex encoded thumbprint of the certificate.
         :param str client_id: The OAuth client id of the calling application.
-        :param list[str] scopes (optional):  Scopes requested to access a protected API (a resource)
+        :param list[str] or None scopes:  Scopes requested to access a protected API (a resource)
 
         """
-        self.authentication_context.with_client_certificate(tenant, client_id, thumbprint, cert_path, **kwargs)
+        self.authentication_context.with_client_certificate(tenant, client_id, thumbprint, cert_path, private_key,
+                                                            scopes)
         return self
 
     def with_access_token(self, token_func):
@@ -330,22 +332,35 @@ class ClientContext(ClientRuntimeContext):
         """Gets the user context for the present request"""
         return RequestUserContext(self, ResourcePath("Me"))
 
+    @property
+    def ee(self):
+        """Alias to EmployeeEngagement"""
+        from office365.sharepoint.viva.employee_engagement import EmployeeEngagement
+        return EmployeeEngagement(self)
+
     @property
     def micro_service_manager(self):
         """Alias to MicroServiceManager"""
         from office365.sharepoint.microservice.manager import MicroServiceManager
         return MicroServiceManager(self, ResourcePath("microServiceManager"))
 
+    @property
+    def models(self):
+        """Alias to collection of SPMachineLearningModel"""
+        from office365.sharepoint.contentcenter.machinelearning.model import SPMachineLearningModel
+        from office365.sharepoint.base_entity_collection import BaseEntityCollection
+        return BaseEntityCollection(self, SPMachineLearningModel, ResourcePath("models"))
+
     @property
     def group_site_manager(self):
         """Alias to GroupSiteManager"""
-        from office365.sharepoint.portal.group_site_manager import GroupSiteManager
+        from office365.sharepoint.portal.groups.site_manager import GroupSiteManager
         return GroupSiteManager(self, ResourcePath("groupSiteManager"))
 
     @property
     def group_service(self):
         """Alias to GroupService"""
-        from office365.sharepoint.portal.group_service import GroupService
+        from office365.sharepoint.portal.groups.service import GroupService
         return GroupService(self, ResourcePath("GroupService"))
 
     @property
@@ -379,19 +394,19 @@ class ClientContext(ClientRuntimeContext):
     @property
     def site_icon_manager(self):
         """Alias to Microsoft.SharePoint.Portal.SiteIconManager. """
-        from office365.sharepoint.portal.site_icon_manager import SiteIconManager
+        from office365.sharepoint.portal.sites.icon_manager import SiteIconManager
         return SiteIconManager(self, ResourcePath("SiteIconManager"))
 
     @property
     def site_linking_manager(self):
         """Alias to Microsoft.SharePoint.Portal.SiteLinkingManager. """
-        from office365.sharepoint.portal.site_linking_manager import SiteLinkingManager
+        from office365.sharepoint.portal.sites.linking_manager import SiteLinkingManager
         return SiteLinkingManager(self, ResourcePath("siteLinkingManager"))
 
     @property
     def site_manager(self):
         """Alias to SPSiteManager. Represents methods for creating and managing SharePoint sites"""
-        from office365.sharepoint.portal.site_manager import SPSiteManager
+        from office365.sharepoint.portal.sites.manager import SPSiteManager
         return SPSiteManager(self, ResourcePath("spSiteManager"))
 
     @property
@@ -415,7 +430,7 @@ class ClientContext(ClientRuntimeContext):
     @property
     def tenant_settings(self):
         """Alias to TenantSettings"""
-        from office365.sharepoint.tenant.tenant_settings import TenantSettings
+        from office365.sharepoint.tenant.settings import TenantSettings
         return TenantSettings.current(self)
 
     @property
