@@ -30,9 +30,10 @@ class RelatedField(BaseEntity):
         return self.properties.get("WebId", None)
 
     @property
-    def relationship_delete_dehavior(self):
+    def relationship_delete_behavior(self):
         """
         Gets delete behavior of the corresponding Lookup Field.
+
         :rtype: int or None
         """
         return self.properties.get("RelationshipDeleteBehavior", None)
@@ -44,3 +45,16 @@ class RelatedField(BaseEntity):
         return self.properties.get("LookupList",
                                    List(self.context, ResourcePath("LookupList", self.resource_path)))
 
+    def set_property(self, name, value, persist_changes=True):
+        super(RelatedField, self).set_property(name, value, persist_changes)
+        if name == "FieldId" and self._resource_path is None:
+            self._resource_path = self.parent_collection.get_by_field_id(value).resource_path
+        return self
+
+    def get_property(self, name, default_value=None):
+        if default_value is None:
+            property_mapping = {
+                "LookupList": self.lookup_list
+            }
+            default_value = property_mapping.get(name, None)
+        return super(RelatedField, self).get_property(name, default_value)
