@@ -3,13 +3,15 @@ from office365.runtime.client_value import ClientValue
 
 class XmlSchemaFieldCreationInformation(ClientValue):
 
-    def __init__(self, schemaXml=None, options=None):
+    def __init__(self, schema_xml=None, options=None):
         """
-        :type schemaXml: str
-        :type options: int or None
+        Specifies metadata about a field
+
+        :param str schema_xml: Specifies the schema that defines the field
+        :param int or None options: Specifies the control settings that are used while adding a field
         """
         super(XmlSchemaFieldCreationInformation, self).__init__()
-        self.SchemaXml = schemaXml
+        self.SchemaXml = schema_xml
         self.Options = options
 
     @property
