@@ -1,3 +1,5 @@
+import json
+
 from office365.runtime.client_result import ClientResult
 from office365.runtime.client_value_collection import ClientValueCollection
 from office365.runtime.queries.service_operation import ServiceOperationQuery
@@ -7,6 +9,7 @@ from office365.sharepoint.base_entity_collection import BaseEntityCollection
 from office365.sharepoint.changes.collection import ChangeCollection
 from office365.sharepoint.changes.query import ChangeQuery
 from office365.sharepoint.comments.collection import CommentCollection
+from office365.sharepoint.fields.image_value import ImageFieldValue
 from office365.sharepoint.fields.lookup_value import FieldLookupValue
 from office365.sharepoint.fields.multi_lookup_value import FieldMultiLookupValue
 from office365.sharepoint.likes.liked_by_information import LikedByInformation
@@ -15,12 +18,12 @@ from office365.sharepoint.listitems.form_update_value import ListItemFormUpdateV
 from office365.sharepoint.listitems.version import ListItemVersion
 from office365.sharepoint.permissions.securable_object import SecurableObject
 from office365.sharepoint.reputationmodel.reputation import Reputation
-from office365.sharepoint.sharing.external_sharing_site_option import ExternalSharingSiteOption
+from office365.sharepoint.sharing.external_site_option import ExternalSharingSiteOption
 from office365.sharepoint.sharing.object_sharing_information import ObjectSharingInformation
-from office365.sharepoint.sharing.share_link_request import ShareLinkRequest
-from office365.sharepoint.sharing.share_link_response import ShareLinkResponse
-from office365.sharepoint.sharing.share_link_settings import ShareLinkSettings
-from office365.sharepoint.sharing.sharing_result import SharingResult
+from office365.sharepoint.sharing.links.share_request import ShareLinkRequest
+from office365.sharepoint.sharing.links.share_response import ShareLinkResponse
+from office365.sharepoint.sharing.links.share_settings import ShareLinkSettings
+from office365.sharepoint.sharing.result import SharingResult
 from office365.sharepoint.taxonomy.field_value import TaxonomyFieldValueCollection
 from office365.sharepoint.ui.applicationpages.peoplepicker.web_service_interface import (
     ClientPeoplePickerWebServiceInterface
@@ -123,7 +126,6 @@ class ListItem(SecurableObject):
         Gets the full URL to the SharePoint frame page that initiates the SPWOPIAction object with the WOPI
             application associated with the list item.
 
-
         :param int action: Indicates which user action is indicated in the returned WOPIFrameUrl.
         """
         result = ClientResult(self.context)
@@ -163,7 +165,6 @@ class ListItem(SecurableObject):
         :param bool send_email: A flag to determine if an email notification SHOULD be sent (if email is configured).
         :param str email_subject: The email subject.
         :param str email_body: The email subject.
-        :rtype: SharingResult
         """
 
         return_type = SharingResult(self.context)
@@ -185,14 +186,11 @@ class ListItem(SecurableObject):
             self.context.after_execute(_picker_value_resolved, True, picker_result)
 
         self.ensure_property("EncodedAbsUrl", _property_resolved)
-
         return return_type
 
     def unshare(self):
         """
         Unshare a ListItem (file or folder facet)
-
-        :rtype: SharingResult
         """
         return_type = SharingResult(self.context)
 
@@ -207,13 +205,12 @@ class ListItem(SecurableObject):
     def get_sharing_information(self):
         """
         Retrieves information about the sharing state for a given list item.
-
         """
         return_type = ObjectSharingInformation(self.context)
 
         def _item_resolved():
             ObjectSharingInformation.get_list_item_sharing_information(
-                self.context, self.parent_list.properties["Id"], self.properties["Id"], return_type=return_type)
+                self.context, self.parent_list.id, self.id, return_type=return_type)
 
         self.ensure_properties(["Id", "ParentList"], _item_resolved)
         return return_type
@@ -282,6 +279,22 @@ class ListItem(SecurableObject):
         self.context.add_query(qry)
         return return_type
 
+    def override_policy_tip(self, user_action, justification):
+        """
+        Overrides the policy tip on this list item.
+
+        :param int user_action: The user action to take.
+        :param str justification: The reason why the override is being done.
+        """
+        return_type = ClientResult(self.context)
+        payload = {
+            "userAction": user_action,
+            "justification": justification
+        }
+        qry = ServiceOperationQuery(self, "OverridePolicyTip", None, payload, None, return_type)
+        self.context.add_query(qry)
+        return return_type
+
     def parse_and_set_field_value(self, field_name, value):
         """Sets the value of the field (2) for the list item based on an implementation-specific transformation
            of the value.
@@ -422,6 +435,8 @@ class ListItem(SecurableObject):
         if persist_changes:
             if isinstance(value, TaxonomyFieldValueCollection):
                 self._set_taxonomy_field_value(name, value)
+            elif isinstance(value, ImageFieldValue):
+                super(ListItem, self).set_property(name, json.dumps(value.to_json()), persist_changes)
             elif isinstance(value, FieldMultiLookupValue):
                 collection = ClientValueCollection(int, [v.LookupId for v in value])
                 super(ListItem, self).set_property("{name}Id".format(name=name), collection)
