@@ -7,7 +7,7 @@ from office365.sharepoint.changes.collection import ChangeCollection
 from office365.sharepoint.changes.query import ChangeQuery
 from office365.sharepoint.changes.token import ChangeToken
 from office365.sharepoint.contenttypes.collection import ContentTypeCollection
-from office365.sharepoint.customactions.element import CustomActionElementCollection
+from office365.sharepoint.customactions.element_collection import CustomActionElementCollection
 from office365.sharepoint.eventreceivers.definition_collection import EventReceiverDefinitionCollection
 from office365.sharepoint.fields.collection import FieldCollection
 from office365.sharepoint.fields.related_field_collection import RelatedFieldCollection
@@ -21,6 +21,7 @@ from office365.sharepoint.listitems.creation_information_using_path import ListI
 from office365.sharepoint.listitems.form_update_value import ListItemFormUpdateValue
 from office365.sharepoint.listitems.listitem import ListItem
 from office365.sharepoint.listitems.collection import ListItemCollection
+from office365.sharepoint.lists.bloom_filter import ListBloomFilter
 from office365.sharepoint.lists.creatables_info import CreatablesInfo
 from office365.sharepoint.lists.data_source import ListDataSource
 from office365.sharepoint.lists.rule import SPListRule
@@ -28,10 +29,10 @@ from office365.sharepoint.pages.wiki_page_creation_information import WikiPageCr
 from office365.sharepoint.permissions.securable_object import SecurableObject
 from office365.sharepoint.principal.user import User
 from office365.sharepoint.sitescripts.utility import SiteScriptUtility
-from office365.sharepoint.types.user_resource import UserResource
+from office365.sharepoint.translation.user_resource import UserResource
 from office365.sharepoint.usercustomactions.collection import UserCustomActionCollection
 from office365.sharepoint.views.view import View
-from office365.sharepoint.views.view_collection import ViewCollection
+from office365.sharepoint.views.collection import ViewCollection
 from office365.sharepoint.webhooks.subscription_collection import SubscriptionCollection
 from office365.sharepoint.utilities.utility import Utility
 from office365.sharepoint.types.resource_path import ResourcePath as SPResPath
@@ -47,6 +48,27 @@ class List(SecurableObject):
     def __init__(self, context, resource_path=None):
         super(List, self).__init__(context, resource_path)
 
+    def delete_rule(self, rule_id):
+        """
+        :param str rule_id:
+        """
+        payload = {"ruleId": rule_id}
+        qry = ServiceOperationQuery(self, "DeleteRule", None, payload)
+        self.context.add_query(qry)
+        return self
+
+    def get_bloom_filter(self, start_item_id=None):
+        """
+        Generates a Bloom filter (probabilistic structure for checking the existence of list items) for the current list
+
+        :param int start_item_id: he ID of the list item to start the search at.
+        """
+        return_type = ListBloomFilter(self.context)
+        payload = {"startItemId": start_item_id}
+        qry = ServiceOperationQuery(self, "GetBloomFilter", None, payload, None, return_type)
+        self.context.add_query(qry)
+        return return_type
+
     def get_site_script(self, options=None):
         """Creates site script syntax
 
@@ -61,12 +83,18 @@ class List(SecurableObject):
         return return_type
 
     def get_all_rules(self):
+        """
+
+        """
         return_type = ClientResult(self.context, ClientValueCollection(SPListRule))
         qry = ServiceOperationQuery(self, "GetAllRules", None, None, None, return_type)
         self.context.add_query(qry)
         return return_type
 
     def get_business_app_operation_status(self):
+        """
+
+        """
         return_type = FlowSynchronizationResult(self.context)
         qry = ServiceOperationQuery(self, "GetBusinessAppOperationStatus", None, None, None, return_type)
         self.context.add_query(qry)
@@ -198,6 +226,8 @@ class List(SecurableObject):
     def get_lookup_field_choices(self, target_field_name, paging_info=None):
         """
 
+        :param str target_field_name:
+        :param str paging_info:
         """
         result = ClientResult(self.context)
         params = {
@@ -220,6 +250,28 @@ class List(SecurableObject):
         self.context.add_query(qry)
         return result
 
+    def save_as_new_view(self, old_name, new_name, private_view, uri):
+        """
+        Overwrites a view if it already exists, creates a new view if it does not; and then extracts the
+        implementation-specific filter and sort information from the URL and builds and updates the view's XML.
+        Returns the URL of the view.
+
+        :param str old_name: The name of the view the user is currently on.
+        :param str new_name: The new name given by the user.
+        :param bool private_view: Set to "true" to make the view private; otherwise, "false".
+        :param str uri: URL that contains all the implementation-specific filter and sort information for the view.
+        """
+        payload = {
+            "oldName": old_name,
+            "newName": new_name,
+            "privateView": private_view,
+            "uri": uri
+        }
+        return_type = ClientResult(self.context)
+        qry = ServiceOperationQuery(self, "SaveAsNewView", None, payload, None, return_type)
+        self.context.add_query(qry)
+        return self
+
     def save_as_template(self, file_name, name, description, save_data):
         """
         Saves the list as a template in the list template gallery and includes the option of saving with or
@@ -400,17 +452,36 @@ class List(SecurableObject):
         """
         Reserves the returned list item identifier for the idempotent creation of a list item.
         """
-        result = ClientResult(self.context)
-        qry = ServiceOperationQuery(self, "ReserveListItemId", None, None, None, result)
+        return_type = ClientResult(self.context)
+        qry = ServiceOperationQuery(self, "ReserveListItemId", None, None, None, return_type)
         self.context.add_query(qry)
-        return result
+        return return_type
 
     def get_related_fields(self):
-        """Returns a collection of lookup fields that use this list as a data source and
-            that have FieldLookup.IsRelationship set to true.
+        """
+        Returns a collection of lookup fields that use this list as a data source and
+        that have FieldLookup.IsRelationship set to true.
         """
         return RelatedFieldCollection(self.context, ServiceOperationPath("getRelatedFields", [], self.resource_path))
 
+    def get_special_folder_url(self, folder_type, force_create, existing_folder_guid):
+        """
+        Gets the relative URL of the Save to OneDrive folder.
+
+        :param int folder_type: The Save-to-OneDrive type.
+        :param bool force_create: Specify true if the folder doesn't exist and SHOULD be created.
+        :param str existing_folder_guid:  The GUID of the created folders that exist, if any.
+        """
+        payload = {
+            "type": folder_type,
+            "bForceCreate": force_create,
+            "existingFolderGuid": existing_folder_guid
+        }
+        return_type = ClientResult(self.context)
+        qry = ServiceOperationQuery(self, "GetSpecialFolderUrl", None, payload, None, return_type)
+        self.context.add_query(qry)
+        return return_type
+
     @property
     def id(self):
         """
@@ -684,6 +755,13 @@ class List(SecurableObject):
         """
         return self.properties.get("ValidationFormula", None)
 
+    @property
+    def parent_collection(self):
+        """
+        :rtype: office365.sharepoint.lists.collection.ListCollection
+        """
+        return self._parent_collection
+
     def get_property(self, name, default_value=None):
         if default_value is None:
             property_mapping = {
@@ -709,6 +787,5 @@ class List(SecurableObject):
         # fallback: create a new resource path
         if self._resource_path is None:
             if name == "Id":
-                self._resource_path = ServiceOperationPath(
-                    "GetById", [value], self._parent_collection.resource_path)
+                self._resource_path = self.parent_collection.get_by_id(value).resource_path
         return self
