@@ -1,7 +1,7 @@
 from office365.runtime.queries.service_operation import ServiceOperationQuery
 from office365.runtime.paths.resource_path import ResourcePath
 from office365.sharepoint.base_entity import BaseEntity
-from office365.sharepoint.tenant.administration.hub_site_collection import HubSiteCollection
+from office365.sharepoint.tenant.administration.hubsites.collection import HubSiteCollection
 
 
 class SPHubSitesUtility(BaseEntity):
