@@ -9,11 +9,12 @@ from office365.sharepoint.changes.token import ChangeToken
 from office365.sharepoint.eventreceivers.definition_collection import EventReceiverDefinitionCollection
 from office365.sharepoint.features.collection import FeatureCollection
 from office365.sharepoint.lists.list import List
-from office365.sharepoint.portal.site_icon_manager import SiteIconManager
+from office365.sharepoint.portal.sites.icon_manager import SiteIconManager
 from office365.sharepoint.principal.user import User
 from office365.sharepoint.recyclebin.item_collection import RecycleBinItemCollection
 from office365.sharepoint.sitehealth.summary import SiteHealthSummary
 from office365.sharepoint.sites.sph_site import SPHSite
+from office365.sharepoint.sites.upgrade_info import UpgradeInfo
 from office365.sharepoint.sites.usage_info import UsageInfo
 from office365.sharepoint.usercustomactions.collection import UserCustomActionCollection
 from office365.sharepoint.webs.web import Web
@@ -27,10 +28,38 @@ class Site(BaseEntity):
     def __init__(self, context, resource_path=None):
         super(Site, self).__init__(context, ResourcePath("Site", resource_path))
 
+    def create_preview_site(self, upgrade=None, sendemail=None):
+        """
+        Schedules the creation of an evaluation copy of the site collection for the purposes of evaluating an upgrade
+        of the site collection to a newer version
+
+        :param bool upgrade: If "true", the evaluation site collection MUST be upgraded when it is created.
+            If "false", the evaluation site collection MUST NOT be upgraded when it is created
+        :param bool sendemail: If "true", a notification email MUST be sent to the requestor and the site collection
+            administrators at the completion of the creation of the evaluation site collection. If "false",
+            such notification MUST NOT be sent
+        """
+        payload = {
+            "upgrade": upgrade,
+            "sendemail": sendemail
+        }
+        qry = ServiceOperationQuery(self, "CreatePreviewSPSite", None, payload)
+        self.context.add_query(qry)
+        return self
+
+    def certify_site(self):
+        """"""
+        return_type = ClientResult(self.context)
+        qry = ServiceOperationQuery(self, "CertifySite", None, None, None, return_type)
+        self.context.add_query(qry)
+        return return_type
+
     def delete_object(self):
         """Deletes a site"""
+
         def _site_resolved():
             self.context.group_site_manager.delete(self.url)
+
         self.ensure_property("Url", _site_resolved)
         return self
 
@@ -66,6 +95,18 @@ class Site(BaseEntity):
         site_manager.set_site_logo(relative_logo_url=relative_logo_url)
         return self
 
+    def is_comm_site(self):
+        """
+        Determines whether a site is communication site
+        """
+        return_type = ClientResult(self.context)
+
+        def _site_loaded():
+            SPHSite.is_comm_site(self.context, self.url, return_type)
+
+        self.ensure_property("Url", _site_loaded)
+        return return_type
+
     def is_valid_home_site(self):
         """
         Determines whether a site is landing site for your intranet.
@@ -139,6 +180,33 @@ class Site(BaseEntity):
         self.context.add_query(qry)
         return return_type
 
+    def invalidate(self):
+        """
+        Invalidates cached upgrade information about the site collection so that this information will be
+        recomputed the next time it is needed
+        """
+        qry = ServiceOperationQuery(self, "Invalidate")
+        self.context.add_query(qry)
+        return self
+
+    def needs_upgrade_by_type(self, version_upgrade, recursive):
+        """
+        Returns "true" if this site collection requires site collection upgrade of the specified type;
+        otherwise, "false"
+
+        :param bool version_upgrade: If "true", version-to-version site collection upgrade is requested;
+            otherwise "false" for build-to-build site collection upgrade.
+        :param bool recursive: If "true", child upgradable objects will be inspected; otherwise "false".
+        """
+        return_type = ClientResult(self.context)
+        payload = {
+            "versionUpgrade": version_upgrade,
+            "recursive": recursive,
+        }
+        qry = ServiceOperationQuery(self, "NeedsUpgradeByType", None, payload, None, return_type)
+        self.context.add_query(qry)
+        return return_type
+
     def join_hub_site(self, hub_site_id, approval_token=None, approval_correlation_id=None):
         """
         Associates a site with an existing hub site.
@@ -189,7 +257,7 @@ class Site(BaseEntity):
             "stopRedirect": stop_redirect,
             "webId": web_id
         }
-        qry = ServiceOperationQuery(context.site, "GetUrlById", None, payload, None, result)
+        qry = ServiceOperationQuery(context.site, "GetUrlByIdForWeb", None, payload, None, result)
         qry.static = True
         context.add_query(qry)
         return result
@@ -279,6 +347,19 @@ class Site(BaseEntity):
         self.context.add_query(qry)
         return self
 
+    def update_client_object_model_use_remote_apis_permission_setting(self, require_use_remote_apis):
+        """
+        Sets whether the client-side object model (CSOM) requests that are made in the context of any site inside
+        the site collection require UseRemoteAPIs permission.
+
+        :param bool require_use_remote_apis: Specifies whether the client-side object model (CSOM) requests that are
+            made in the context of any site inside the site collection require UseRemoteAPIs permission
+        """
+        payload = {"requireUseRemoteAPIs": require_use_remote_apis}
+        qry = ServiceOperationQuery(self, "UpdateClientObjectModelUseRemoteAPIsPermissionSetting", None, payload)
+        self.context.add_query(qry)
+        return self
+
     @property
     def allow_designer(self):
         """
@@ -469,6 +550,11 @@ class Site(BaseEntity):
         """Provides fields used to access information regarding site collection usage."""
         return self.properties.get("UsageInfo", UsageInfo())
 
+    @property
+    def upgrade_info(self):
+        """Specifies the upgrade information of this site collection."""
+        return self.properties.get("UpgradeInfo", UpgradeInfo())
+
     @property
     def user_custom_actions(self):
         """Gets the User Custom Actions that are associated with the site."""
@@ -485,6 +571,7 @@ class Site(BaseEntity):
                 "RootWeb": self.root_web,
                 "SecondaryContact": self.secondary_contact,
                 "UsageInfo": self.usage_info,
+                "UpgradeInfo": self.upgrade_info,
                 "UserCustomActions": self.user_custom_actions
             }
             default_value = property_mapping.get(name, None)
