@@ -5,7 +5,7 @@ from office365.runtime.client_value import ClientValue
 
 
 class ContextWebInformation(ClientValue):
-    """Specifies metadata about a site (2)."""
+    """Specifies metadata about a site."""
 
     def __init__(self, form_digest_value=None, form_digest_timeout_secs=None):
         """
@@ -26,8 +26,11 @@ class ContextWebInformation(ClientValue):
 
     @property
     def is_valid(self):
+        """
+        Determines whether FormDigest has been expired or not
+        """
         if self.FormDigestTimeoutSeconds is None:
             return False
-        else:
-            expires_in_sec = math.ceil(time.time() - self._valid_from)
-            return expires_in_sec < self.FormDigestTimeoutSeconds
+
+        expires_in_sec = math.ceil(time.time() - self._valid_from)
+        return expires_in_sec < self.FormDigestTimeoutSeconds
