@@ -6,8 +6,11 @@ from office365.runtime.paths.resource_path import ResourcePath
 from office365.runtime.paths.service_operation import ServiceOperationPath
 from office365.sharepoint.activities.entity import SPActivityEntity
 from office365.sharepoint.alerts.collection import AlertCollection
+from office365.sharepoint.authentication.acs_service_principal_info import SPACSServicePrincipalInfo
 from office365.sharepoint.base_entity_collection import BaseEntityCollection
+from office365.sharepoint.businessdata.app_bdc_catalog import AppBdcCatalog
 from office365.sharepoint.changes.collection import ChangeCollection
+from office365.sharepoint.clientsidecomponent.hostedapps.manager import HostedAppsManager
 from office365.sharepoint.clientsidecomponent.storage_entity import StorageEntity
 from office365.sharepoint.clientsidecomponent.query_result import SPClientSideComponentQueryResult
 from office365.sharepoint.clientsidecomponent.identifier import SPClientSideComponentIdentifier
@@ -33,13 +36,15 @@ from office365.sharepoint.principal.user import User
 from office365.sharepoint.principal.user_collection import UserCollection
 from office365.sharepoint.pushnotifications.subscriber import PushNotificationSubscriber
 from office365.sharepoint.recyclebin.item_collection import RecycleBinItemCollection
-from office365.sharepoint.sharing.external_sharing_site_option import ExternalSharingSiteOption
+from office365.sharepoint.sharing.external_site_option import ExternalSharingSiteOption
+from office365.sharepoint.sharing.links.access_request import SharingLinkAccessRequest
 from office365.sharepoint.sharing.object_sharing_settings import ObjectSharingSettings
-from office365.sharepoint.sharing.sharing_link_data import SharingLinkData
-from office365.sharepoint.sharing.sharing_result import SharingResult
+from office365.sharepoint.sharing.links.data import SharingLinkData
+from office365.sharepoint.sharing.result import SharingResult
 from office365.sharepoint.sitescripts.utility import SiteScriptUtility
 from office365.sharepoint.marketplace.sitecollection.appcatalog.accessor import SiteCollectionCorporateCatalogAccessor
 from office365.sharepoint.marketplace.tenant.appcatalog.accessor import TenantCorporateCatalogAccessor
+from office365.sharepoint.translation.user_resource import UserResource
 from office365.sharepoint.ui.applicationpages.peoplepicker.web_service_interface import (
     ClientPeoplePickerWebServiceInterface
 )
@@ -55,6 +60,7 @@ from office365.sharepoint.sitescripts.types import SiteScriptSerializationResult
 from office365.sharepoint.webs.information_collection import WebInformationCollection
 from office365.sharepoint.webs.template_collection import WebTemplateCollection
 from office365.sharepoint.types.resource_path import ResourcePath as SPResPath
+from office365.sharepoint.webs.theme_info import ThemeInfo
 
 
 class Web(SecurableObject):
@@ -249,6 +255,15 @@ class Web(SecurableObject):
         self.context.add_query(qry)
         return return_type
 
+    def list_acs_service_principals(self):
+        """
+        List service principals
+        """
+        return_type = ClientResult(self.context, ClientValueCollection(SPACSServicePrincipalInfo))
+        qry = ServiceOperationQuery(self, "ListACSServicePrincipals", None, None, None, return_type)
+        self.context.add_query(qry)
+        return return_type
+
     def sync_flow_instances(self, target_web_url):
         """
         :param str target_web_url:
@@ -271,10 +286,22 @@ class Web(SecurableObject):
 
     def get_all_client_side_components(self):
         result = ClientResult(self.context)
-        qry = ServiceOperationQuery(self, "getAllClientSideComponents", None, None, None, result)
+        qry = ServiceOperationQuery(self, "GetAllClientSideComponents", None, None, None, result)
         self.context.add_query(qry)
         return result
 
+    def get_app_bdc_catalog(self):
+        """
+        Returns the Business Data Connectivity (BDC) MetadataCatalog for an application that gives access to the
+        external content types defined in the BDC metadata model packaged by the application.<151>
+        This method SHOULD be called on the Web (section 3.2.5.143) object that represents the site for the application
+        and it returns the BDC MetadataCatalog deployed on the site.
+        """
+        return_type = AppBdcCatalog(self.context)
+        qry = ServiceOperationQuery(self, "GetAppBdcCatalog", None, None, None, return_type)
+        self.context.add_query(qry)
+        return return_type
+
     def get_client_side_web_parts(self, project, include_errors=False):
         """
         :param str project:
@@ -436,6 +463,17 @@ class Web(SecurableObject):
         context.add_query(qry)
         return result
 
+    def create_site_page(self, page_metadata):
+        """Create a site page
+
+        :param str page_metadata:
+        """
+        payload = {"pageMetaData": page_metadata}
+        return_type = ClientResult(self.context)
+        qry = ServiceOperationQuery(self, "CreateSitePage", None, payload, None, return_type)
+        self.context.add_query(qry)
+        return return_type
+
     @staticmethod
     def create_anonymous_link(context, url, is_edit_link):
         """Create an anonymous link which can be used to access a document without needing to authenticate.
@@ -455,6 +493,31 @@ class Web(SecurableObject):
         context.add_query(qry)
         return result
 
+    @staticmethod
+    def create_anonymous_link_with_expiration(context, url, is_edit_link, expiration_string):
+        """
+        Creates and returns an anonymous link that can be used to access a document without needing to authenticate.
+
+        :param bool is_edit_link: If true, the link will allow the guest user edit privileges on the item.
+        :param str url: The URL of the site, with the path of the object in SharePoint represented as query
+        string parameters
+        :param str expiration_string: A date/time string for which the format conforms to the ISO 8601:2004(E) complete
+        representation for calendar date and time of day, and which represents the time and date of expiry for the
+        anonymous link. Both the minutes and hour value MUST be specified for the difference between the local and
+        UTC time. Midnight is represented as 00:00:00.
+        :param office365.sharepoint.client_context.ClientContext context: client context
+        """
+        result = ClientResult(context)
+        payload = {
+            "url": context.create_safe_url(url, False),
+            "isEditLink": is_edit_link,
+            "expirationString": expiration_string
+        }
+        qry = ServiceOperationQuery(context.web, "CreateAnonymousLinkWithExpiration", None, payload, None, result)
+        qry.static = True
+        context.add_query(qry)
+        return result
+
     @staticmethod
     def get_object_sharing_settings(context, object_url, group_id, use_simplified_roles):
         """Given a path to an object in SharePoint, this will generate a sharing settings object which contains
@@ -682,6 +745,44 @@ class Web(SecurableObject):
         self.context.add_query(qry)
         return return_type
 
+    def get_file_by_guest_url_extended(self, guest_url, ensure_access=None, password=None):
+        """
+        Returns the file object from the tokenized sharing link URL.
+
+        :param str guest_url: The tokenized sharing link URL for the folder.
+        :param str password: This value contains the password to be supplied to a tokenized sharing link for validation.
+             This value is only needed if the link requires a password before granting access and the calling user
+             does not currently have perpetual access through the tokenized sharing link.
+             This value MUST be set to the correct password for the tokenized sharing link for the access granting
+             operation to succeed. If the tokenized sharing link does not require a password or the calling user
+             already has perpetual access through the tokenized sharing link, this value will be ignored.
+        :param bool ensure_access: Indicates if the request to the tokenized sharing link grants perpetual access to
+            the calling user.
+        """
+        return_type = File(self.context)
+        payload = {
+            "guestUrl": guest_url,
+            "requestSettings": SharingLinkAccessRequest(ensure_access, password)
+        }
+        qry = ServiceOperationQuery(self, "GetFileByGuestUrlExtended", None, payload, None, return_type)
+        self.context.add_query(qry)
+        return return_type
+
+    def get_file_by_guest_url_ensure_access(self, guest_url, ensure_access):
+        """
+        Returns the file object from the tokenized sharing link URL.
+
+        :param str guest_url: The guest access URL to get the file with.
+        :param bool ensure_access:  Indicates if the request to the tokenized sharing link grants perpetual access to
+            the calling user. If it is set to true then the user who is requesting the file will be granted perpetual
+            permissions through the tokenized sharing link.
+        """
+        return_type = File(self.context)
+        payload = {"guestUrl": guest_url, "ensureAccess": ensure_access}
+        qry = ServiceOperationQuery(self, "GetFileByGuestUrlEnsureAccess", None, payload, None, return_type)
+        self.context.add_query(qry)
+        return return_type
+
     def get_file_by_linking_url(self, linking_url):
         """
         Returns the file object from the linking URL.
@@ -695,6 +796,18 @@ class Web(SecurableObject):
         self.context.add_query(qry)
         return return_type
 
+    def get_file_by_url(self, file_url):
+        """
+        Returns the file object from the given URL.
+
+        :param str file_url: The URL used to get the file object.
+        """
+        return_type = File(self.context)
+        params = {"fileUrl": file_url}
+        qry = ServiceOperationQuery(self, "GetFileByUrl", params, None, None, return_type)
+        self.context.add_query(qry)
+        return return_type
+
     def get_file_by_wopi_frame_url(self, wopi_frame_url):
         """
         Returns the file object from the WOPI frame URL.
@@ -712,8 +825,32 @@ class Web(SecurableObject):
 
         :param str guest_url: The tokenized sharing link URL for the folder.
         """
-        return_type = File(self.context)
-        qry = ServiceOperationQuery(self, "GetFolderByGuestUrl", [guest_url], None, None, return_type)
+        return_type = Folder(self.context)
+        payload = {"guestUrl": guest_url}
+        qry = ServiceOperationQuery(self, "GetFolderByGuestUrl", None, payload, None, return_type)
+        self.context.add_query(qry)
+        return return_type
+
+    def get_folder_by_guest_url_extended(self, guest_url, ensure_access=None, password=None):
+        """
+        Returns the folder object from the tokenized sharing link URL.
+
+        :param str guest_url: The tokenized sharing link URL for the folder.
+        :param str password: This value contains the password to be supplied to a tokenized sharing link for validation.
+             This value is only needed if the link requires a password before granting access and the calling user
+             does not currently have perpetual access through the tokenized sharing link.
+             This value MUST be set to the correct password for the tokenized sharing link for the access granting
+             operation to succeed. If the tokenized sharing link does not require a password or the calling user
+             already has perpetual access through the tokenized sharing link, this value will be ignored.
+        :param bool ensure_access: Indicates if the request to the tokenized sharing link grants perpetual access to
+            the calling user.
+        """
+        return_type = Folder(self.context)
+        payload = {
+            "guestUrl": guest_url,
+            "requestSettings": SharingLinkAccessRequest(ensure_access, password)
+        }
+        qry = ServiceOperationQuery(self, "GetFolderByGuestUrlExtended", None, payload, None, return_type)
         self.context.add_query(qry)
         return return_type
 
@@ -843,6 +980,29 @@ class Web(SecurableObject):
         context.add_query(qry)
         return context.web
 
+    @staticmethod
+    def delete_anonymous_link_for_object(context, url, is_edit_link, remove_associated_sharing_link_group):
+        """
+        Removes an existing anonymous link for an object..
+
+        :param office365.sharepoint.client_context.ClientContext context: SharePoint context
+        :param str url:  The URL of the object being shared, with the path of the object in SharePoint that is
+             represented as query string parameters.
+        :param bool is_edit_link: If true, the edit link for the object will be removed. If false, the view only link
+            for the object will be removed.
+        :param bool remove_associated_sharing_link_group: Indicates whether to remove the groups that contain the users
+        who have been given access to the shared object via the sharing link¹.
+        """
+        payload = {
+            "url": url,
+            "isEditLink": is_edit_link,
+            "removeAssociatedSharingLinkGroup": remove_associated_sharing_link_group
+        }
+        qry = ServiceOperationQuery(context.web, "DeleteAnonymousLinkForObject", None, payload)
+        qry.static = True
+        context.add_query(qry)
+        return context.web
+
     @staticmethod
     def get_document_and_media_libraries(context, web_full_url, include_page_libraries):
         """
@@ -1065,7 +1225,37 @@ class Web(SecurableObject):
         params = {
             "key": key,
         }
-        qry = ServiceOperationQuery(self, "RemoveStorageEntity", params, None, None, None)
+        qry = ServiceOperationQuery(self, "RemoveStorageEntity", params)
+        self.context.add_query(qry)
+        return self
+
+    def remove_supported_ui_language(self, lcid):
+        """
+        Removes a supported UI language by its language identifier.
+
+        :param str lcid: Specifies the language identifier to be removed.
+        """
+        params = {"lcid": lcid}
+        qry = ServiceOperationQuery(self, "RemoveSupportedUILanguage", params)
+        self.context.add_query(qry)
+        return self
+
+    def set_access_request_site_description_and_update(self, description=None):
+        """
+        :param str description:
+        """
+        payload = {"description": description}
+        qry = ServiceOperationQuery(self, "SetAccessRequestSiteDescriptionAndUpdate", None, payload)
+        self.context.add_query(qry)
+        return self
+
+    def set_global_nav_settings(self, title, source):
+        """
+        :param str title:
+        :param str source:
+        """
+        payload = {"title": title, "source": source}
+        qry = ServiceOperationQuery(self, "SetGlobalNavSettings", None, payload)
         self.context.add_query(qry)
         return self
 
@@ -1114,6 +1304,13 @@ class Web(SecurableObject):
         """
         return self.properties.get("CustomMasterUrl", None)
 
+    @property
+    def custom_site_actions_disabled(self):
+        """
+        :rtype: bool or None
+        """
+        return self.properties.get("CustomSiteActionsDisabled", None)
+
     @property
     def id(self):
         """
@@ -1135,22 +1332,34 @@ class Web(SecurableObject):
         """
         return self.properties.get("AccessRequestListUrl", None)
 
+    @property
+    def effective_base_permissions(self):
+        """Specifies the effective permissions that are assigned to the current user"""
+        from office365.sharepoint.permissions.base_permissions import BasePermissions
+        return self.properties.get("EffectiveBasePermissions", BasePermissions())
+
     @property
     def webs(self):
-        """Get child webs"""
+        """Specifies the collection of all child sites for the site"""
         from office365.sharepoint.webs.collection import WebCollection
         return self.properties.get("Webs",
                                    WebCollection(self.context, ResourcePath("webs", self.resource_path), self))
 
     @property
     def folders(self):
-        """Get folder resources"""
+        """Specifies the collection of all first-level folders in the site """
         return self.properties.get('Folders',
                                    FolderCollection(self.context, ResourcePath("folders", self.resource_path), self))
 
+    @property
+    def hosted_apps(self):
+        return self.properties.get('HostedApps',
+                                   HostedAppsManager(self.context, ResourcePath("HostedApps", self.resource_path)))
+
     @property
     def lists(self):
-        """Get web list collection"""
+        """Specifies the collection of lists that are contained in the site available to the current user based on the
+        current user's permissions."""
         return self.properties.get('Lists',
                                    ListCollection(self.context, ResourcePath("lists", self.resource_path)))
 
@@ -1211,6 +1420,12 @@ class Web(SecurableObject):
                                    ContentTypeCollection(self.context,
                                                          ResourcePath("ContentTypes", self.resource_path), self))
 
+    @property
+    def description_resource(self):
+        """A UserResource object that represents the description of this web."""
+        return self.properties.get('DescriptionResource',
+                                   UserResource(self.context, ResourcePath("DescriptionResource", self.resource_path)))
+
     @property
     def role_definitions(self):
         """Gets the collection of role definitions for the Web site."""
@@ -1257,6 +1472,12 @@ class Web(SecurableObject):
         return self.properties.get('WebInfos',
                                    WebInformationCollection(self.context, ResourcePath("WebInfos", self.resource_path)))
 
+    @property
+    def theme_info(self):
+        """Specifies the site theme associated with the site"""
+        return self.properties.get('ThemeInfo',
+                                   ThemeInfo(self.context, ResourcePath("ThemeInfo", self.resource_path)))
+
     @property
     def url(self):
         """Gets the absolute URL for the website.
@@ -1442,6 +1663,12 @@ class Web(SecurableObject):
         """
         return self.properties.get("ServerRelativePath", SPResPath())
 
+    @property
+    def title_resource(self):
+        """A UserResource object that represents the title of this web."""
+        return self.properties.get('TitleResource',
+                                   UserResource(self.context, ResourcePath("TitleResource", self.resource_path)))
+
     def get_property(self, name, default_value=None):
         if default_value is None:
             property_mapping = {
@@ -1454,7 +1681,10 @@ class Web(SecurableObject):
                 "ContentTypes": self.content_types,
                 "ClientWebParts": self.client_web_parts,
                 "CurrentUser": self.current_user,
+                "DescriptionResource": self.description_resource,
+                "EffectiveBasePermissions": self.effective_base_permissions,
                 "EventReceivers": self.event_receivers,
+                "HostedApps": self.hosted_apps,
                 "ListTemplates": self.list_templates,
                 "MultilingualSettings": self.multilingual_settings,
                 "ParentWeb": self.parent_web,
@@ -1468,8 +1698,10 @@ class Web(SecurableObject):
                 "SiteUsers": self.site_users,
                 "SiteUserInfoList": self.site_user_info_list,
                 "TenantAppCatalog": self.tenant_app_catalog,
+                "TitleResource": self.title_resource,
                 "UserCustomActions": self.user_custom_actions,
-                "WebInfos": self.web_infos
+                "WebInfos": self.web_infos,
+                "ThemeInfo": self.theme_info
             }
             default_value = property_mapping.get(name, None)
         return super(Web, self).get_property(name, default_value)
